@@ -105,21 +105,12 @@ def _get_security_group_id(ec2_client: BaseClient, bucket_name: str, subnet_id:
         security_group_id = security_group["GroupId"]
         ip_permissions = [
             {
-                "FromPort": 3000,
-                "ToPort": 4000,
+                "FromPort": 22,
+                "ToPort": 22,
                 "IpProtocol": "tcp",
                 "IpRanges": [{"CidrIp": "0.0.0.0/0"}],
             }
         ]
-        if not version.__is_release__:
-            ip_permissions.append(
-                {
-                    "FromPort": 22,
-                    "ToPort": 22,
-                    "IpProtocol": "tcp",
-                    "IpRanges": [{"CidrIp": "0.0.0.0/0"}],
-                }
-            )
         ec2_client.authorize_security_group_ingress(
             GroupId=security_group_id, IpPermissions=ip_permissions
         )
@@ -166,6 +157,7 @@ def _user_data(
     region_name,
     runner_id: str,
     resources: Resources,
+    ssh_key_pub: str,
     port_range_from: int = 3000,
     port_range_to: int = 4000,
 ) -> str:
@@ -188,6 +180,7 @@ echo $'{_serialize_runner_yaml(runner_id, resources, runner_port_range_from, run
 die() {{ status=$1; shift; echo "FATAL: $*"; exit $status; }}
 EC2_PUBLIC_HOSTNAME="`wget -q -O - http://169.254.169.254/latest/meta-data/public-hostname || die \"wget public-hostname has failed: $?\"`"
 echo "hostname: $EC2_PUBLIC_HOSTNAME" >> /root/.dstack/runner.yaml
+mkdir ~/.ssh; chmod 700 ~/.ssh; echo "{ssh_key_pub}" > ~/.ssh/authorized_keys; chmod 600 ~/.ssh/authorized_keys
 HOME=/root nohup dstack-runner --log-level 6 start --http-port 4000 &
 """
     return user_data
@@ -351,6 +344,7 @@ def _run_instance(
     local_repo_user_name: Optional[str],
     local_repo_user_email: Optional[str],
     repo_address: RepoAddress,
+    ssh_key_pub: str,
 ) -> str:
     launch_specification = {}
     if not version.__is_release__:
@@ -402,7 +396,9 @@ def _run_instance(
         IamInstanceProfile={
             "Arn": _get_instance_profile_arn(iam_client, bucket_name),
         },
-        UserData=_user_data(bucket_name, region_name, runner_id, instance_type.resources),
+        UserData=_user_data(
+            bucket_name, region_name, runner_id, instance_type.resources, ssh_key_pub=ssh_key_pub
+        ),
         TagSpecifications=[
             {
                 "ResourceType": "instance",
@@ -430,6 +426,7 @@ def run_instance_retry(
     local_repo_user_name: Optional[str],
     local_repo_user_email: Optional[str],
     repo_address: RepoAddress,
+    ssh_key_pub: str,
     attempts: int = 3,
 ) -> str:
     try:
@@ -444,6 +441,7 @@ def run_instance_retry(
             local_repo_user_name,
             local_repo_user_email,
             repo_address,
+            ssh_key_pub,
         )
     except Exception as e:
         if (
@@ -464,6 +462,7 @@ def run_instance_retry(
                     local_repo_user_name,
                     local_repo_user_email,
                     repo_address,
+                    ssh_key_pub,
                     attempts - 1,
                 )
             else:
