@@ -37,6 +37,7 @@ class HubBackend(RemoteBackend):
         if self._client is None:
             self._client = HubClient(
                 url=self.backend_config.url,
+                project=self.backend_config.project,
                 token=self.backend_config.token,
             )
         return self._client
@@ -116,6 +117,7 @@ class HubBackend(RemoteBackend):
         repo_address: RepoAddress,
         run_name: str,
         output_dir: Optional[str],
+        files_path: Optional[str] = None,
     ):
         # /{hub_name}/artifacts/download
         artifacts = self.list_run_artifact_files(repo_address=repo_address, run_name=run_name)
@@ -124,6 +126,7 @@ class HubBackend(RemoteBackend):
             repo_address=repo_address,
             artifacts=artifacts,
             output_dir=output_dir,
+            files_path=files_path,
         )
 
     def upload_job_artifact_files(
