@@ -1,6 +1,7 @@
 from argparse import ArgumentParser
 from typing import Any, Dict, List, Optional
 
+from dstack import version
 from dstack.backend.base import Backend
 from dstack.core.app import AppSpec
 from dstack.core.job import JobSpec
@@ -41,6 +42,7 @@ class BashProvider(Provider):
     def _create_parser(self, workflow_name: Optional[str]) -> Optional[ArgumentParser]:
         parser = ArgumentParser(prog="dstack run " + (workflow_name or self.provider_name))
         self._add_base_args(parser)
+        parser.add_argument("--ssh", action="store_true", dest="openssh_server")
         parser.add_argument("-p", "--ports", metavar="PORT_COUNT", type=int)
         if not workflow_name:
             parser.add_argument("-c", "--command", type=str)
@@ -54,18 +56,20 @@ class BashProvider(Provider):
             self.provider_data["commands"] = [args.command]
         if args.ports:
             self.provider_data["ports"] = args.ports
+        if args.openssh_server:
+            self.openssh_server = True
 
     def create_job_specs(self) -> List[JobSpec]:
-        apps = None
-        if self.ports:
-            apps = []
-            for i in range(self.ports):
-                apps.append(
-                    AppSpec(
-                        port_index=i,
-                        app_name="bash" + (str(i) if self.ports > 1 else ""),
-                    )
+        apps = []
+        for i in range(self.ports or 0):
+            apps.append(
+                AppSpec(
+                    port_index=i,
+                    app_name="bash" + (str(i) if self.ports > 1 else ""),
                 )
+            )
+        if self.openssh_server:
+            apps.append(AppSpec(port_index=len(apps), app_name="openssh-server"))
         return [
             JobSpec(
                 image_name=self.image_name,
@@ -73,7 +77,7 @@ class BashProvider(Provider):
                 entrypoint=["/bin/bash", "-i", "-c"],
                 working_dir=self.working_dir,
                 artifact_specs=self.artifact_specs,
-                port_count=self.ports,
+                port_count=len(apps),
                 requirements=self.resources,
                 app_specs=apps,
             )
@@ -81,14 +85,16 @@ class BashProvider(Provider):
 
     def _image_name(self) -> str:
         cuda_is_required = self.resources and self.resources.gpus
-        cuda_image_name = f"dstackai/miniforge:{self.python}-cuda-11.1"
-        cpu_image_name = f"dstackai/miniforge:{self.python}"
+        cuda_image_name = f"dstackai/miniforge:py{self.python}-{version.miniforge_image}-cuda-11.1"
+        cpu_image_name = f"dstackai/miniforge:py{self.python}-{version.miniforge_image}"
         return cuda_image_name if cuda_is_required else cpu_image_name
 
     def _commands(self):
         commands = []
         if self.env:
             self._extend_commands_with_env(commands, self.env)
+        if self.openssh_server:
+            self._extend_commands_with_openssh_server(commands, self.ssh_key_pub, self.ports or 0)
         commands.extend(self.commands)
         return commands
 
