@@ -2,6 +2,7 @@ import uuid
 from argparse import ArgumentParser
 from typing import Any, Dict, List, Optional
 
+from dstack import version
 from dstack.backend.base import Backend
 from dstack.core.app import AppSpec
 from dstack.core.job import JobSpec
@@ -41,17 +42,29 @@ class NotebookProvider(Provider):
     def _create_parser(self, workflow_name: Optional[str]) -> Optional[ArgumentParser]:
         parser = ArgumentParser(prog="dstack run " + (workflow_name or self.provider_name))
         self._add_base_args(parser)
+        parser.add_argument("--ssh", action="store_true", dest="openssh_server")
         return parser
 
     def parse_args(self):
         parser = self._create_parser(self.workflow_name)
         args, unknown_args = parser.parse_known_args(self.provider_args)
         self._parse_base_args(args, unknown_args)
+        if args.openssh_server:
+            self.openssh_server = True
 
     def create_job_specs(self) -> List[JobSpec]:
         env = {}
         token = uuid.uuid4().hex
         env["TOKEN"] = token
+        apps = [
+            AppSpec(
+                port_index=0,
+                app_name="notebook",
+                url_query_params={"token": token},
+            )
+        ]
+        if self.openssh_server:
+            apps.append(AppSpec(port_index=len(apps), app_name="openssh-server"))
         return [
             JobSpec(
                 image_name=self.image_name,
@@ -60,28 +73,24 @@ class NotebookProvider(Provider):
                 env=env,
                 working_dir=self.working_dir,
                 artifact_specs=self.artifact_specs,
-                port_count=1,
+                port_count=len(apps),
                 requirements=self.resources,
-                app_specs=[
-                    AppSpec(
-                        port_index=0,
-                        app_name="notebook",
-                        url_query_params={"token": token},
-                    )
-                ],
+                app_specs=apps,
             )
         ]
 
     def _image_name(self) -> str:
         cuda_is_required = self.resources and self.resources.gpus
-        cuda_image_name = f"dstackai/miniforge:{self.python}-cuda-11.1"
-        cpu_image_name = f"dstackai/miniforge:{self.python}"
+        cuda_image_name = f"dstackai/miniforge:py{self.python}-{version.miniforge_image}-cuda-11.1"
+        cpu_image_name = f"dstackai/miniforge:py{self.python}-{version.miniforge_image}"
         return cuda_image_name if cuda_is_required else cpu_image_name
 
     def _commands(self):
         commands = []
         if self.env:
             self._extend_commands_with_env(commands, self.env)
+        if self.openssh_server:
+            self._extend_commands_with_openssh_server(commands, self.ssh_key_pub, 1)
         commands.extend(
             [
                 "conda install psutil -y",
